@@ -1,10 +1,10 @@
 /*
-**  L2 - OSSP Logging Library
+**  OSSP l2 - Logging Library
 **  Copyright (c) 2001-2002 The OSSP Project (http://www.ossp.org/)
 **  Copyright (c) 2001-2002 Cable & Wireless Deutschland (http://www.cw.com/de/)
 **
 **  This file is part of OSSP L2, a flexible logging library which
-**  can be found at http://www.ossp.org/pkg/l2/.
+**  can be found at http://www.ossp.org/pkg/lib/l2/.
 **
 **  Permission to use, copy, modify, and distribute this software for
 **  any purpose with or without fee is hereby granted, provided that
@@ -297,8 +297,8 @@ static l2_result_t hook_write(l2_context_t *ctx, l2_channel_t *ch,
                                 cfg->szIdent, buf);
         if ((n = strlen(caBuf)) > 1024)
             return L2_ERR_IO;
-        if ((rc = sa_send(cfg->saRemoteSock, caBuf, n, 
-                          NULL, cfg->saaRemoteAddr)) != SA_OK)
+        if ((rc = sa_send(cfg->saRemoteSock, cfg->saaRemoteAddr,
+                          caBuf, n, NULL)) != SA_OK)
             return (rc == SA_ERR_SYS ? L2_ERR_SYS : L2_ERR_IO);
     }
 
